@@ -20,19 +20,18 @@ package org.jpmml.converter;
 
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.Field;
-import org.dmg.pmml.FieldName;
 
 public class StringFeature extends ObjectFeature {
 
 	public StringFeature(PMMLEncoder encoder, Field<?> field){
-		this(encoder, field.getName(), field.getDataType());
+		this(encoder, field.requireName());
 	}
 
 	public StringFeature(PMMLEncoder encoder, Feature feature){
-		this(encoder, feature.getName(), feature.getDataType());
+		this(encoder, feature.getName());
 	}
 
-	public StringFeature(PMMLEncoder encoder, FieldName name, DataType dataType){
-		super(encoder, name, dataType);
+	public StringFeature(PMMLEncoder encoder, String name){
+		super(encoder, name, DataType.STRING);
 	}
 }
\ No newline at end of file
