@@ -20,19 +20,24 @@ package org.jpmml.converter;
 
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.Expression;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.FieldRef;
 import org.dmg.pmml.OpType;
+import org.dmg.pmml.OutputField;
+import org.dmg.pmml.ResultFeature;
 
 public interface Transformation {
 
-	FieldName getName(FieldName name);
+	String getName(String name);
 
 	OpType getOpType(OpType opType);
 
 	DataType getDataType(DataType dataType);
 
+	ResultFeature getResultFeature();
+
 	boolean isFinalResult();
 
 	Expression createExpression(FieldRef fieldRef);
+
+	OutputField createOutputField(OutputField outputField);
 }
\ No newline at end of file
