@@ -22,25 +22,34 @@ import java.util.List;
 import java.util.ListIterator;
 
 import org.dmg.pmml.Apply;
+import org.dmg.pmml.Constant;
 import org.dmg.pmml.Expression;
 import org.dmg.pmml.PMMLFunctions;
 import org.dmg.pmml.VisitorAction;
+import org.jpmml.model.InvalidElementException;
 import org.jpmml.model.visitors.AbstractVisitor;
 
 public class ExpressionCompactor extends AbstractVisitor {
 
 	@Override
 	public VisitorAction visit(Apply apply){
-		String function = apply.getFunction();
+		String function = apply.requireFunction();
 
 		switch(function){
+			case PMMLFunctions.EQUAL:
+			case PMMLFunctions.NOTEQUAL:
+				simplifyComparisonExpression(apply);
+				break;
 			case PMMLFunctions.AND:
 			case PMMLFunctions.OR:
-				inlineLogicalExpressions(apply);
+				inlineNestedExpressions(apply);
 				break;
 			case PMMLFunctions.NOT:
 				negateExpression(apply);
 				break;
+			case PMMLFunctions.CONCAT:
+				inlineNestedExpressions(apply);
+				break;
 			default:
 				break;
 		}
@@ -49,25 +58,63 @@ public class ExpressionCompactor extends AbstractVisitor {
 	}
 
 	static
-	private void inlineLogicalExpressions(Apply apply){
-		String function = apply.getFunction();
+	private void simplifyComparisonExpression(Apply apply){
+		String function = apply.requireFunction();
+		List<Expression> expressions = apply.getExpressions();
+
+		if(expressions.size() != 2){
+			throw new InvalidElementException(apply);
+		}
+
+		ListIterator<Expression> expressionIt = expressions.listIterator();
+		while(expressionIt.hasNext()){
+			Expression expression = expressionIt.next();
+
+			if(isMissingConstant(expression)){
+				expressionIt.remove();
+			}
+		}
+
+		if(expressions.size() == 0){
+			throw new InvalidElementException(apply);
+		} else
+
+		if(expressions.size() == 1){
+
+			switch(function){
+				case PMMLFunctions.EQUAL:
+					apply.setFunction(PMMLFunctions.ISMISSING);
+					break;
+				case PMMLFunctions.NOTEQUAL:
+					apply.setFunction(PMMLFunctions.ISNOTMISSING);
+					break;
+				default:
+					throw new InvalidElementException(apply);
+			}
+		}
+	}
+
+	static
+	private void inlineNestedExpressions(Apply apply){
+		String function = apply.requireFunction();
 		List<Expression> expressions = apply.getExpressions();
 
 		if(expressions.size() < 2){
-			throw new IllegalArgumentException();
+			throw new InvalidElementException(apply);
 		}
 
-		for(ListIterator<Expression> expressionIt = expressions.listIterator(); expressionIt.hasNext(); ){
+		ListIterator<Expression> expressionIt = expressions.listIterator();
+		while(expressionIt.hasNext()){
 			Expression expression = expressionIt.next();
 
 			if(expression instanceof Apply){
 				Apply nestedApply = (Apply)expression;
 
-				if((function).equals(nestedApply.getFunction())){
+				if((function).equals(nestedApply.requireFunction())){
 					expressionIt.remove();
 
 					// Depth first, breadth second
-					inlineLogicalExpressions(nestedApply);
+					inlineNestedExpressions(nestedApply);
 
 					List<Expression> nestedExpressions = nestedApply.getExpressions();
 					for(Expression nestedExpression : nestedExpressions){
@@ -83,7 +130,7 @@ public class ExpressionCompactor extends AbstractVisitor {
 		List<Expression> expressions = apply.getExpressions();
 
 		if(expressions.size() != 1){
-			throw new IllegalArgumentException();
+			throw new InvalidElementException(apply);
 		}
 
 		ListIterator<Expression> expressionIt = expressions.listIterator();
@@ -93,7 +140,7 @@ public class ExpressionCompactor extends AbstractVisitor {
 		if(expression instanceof Apply){
 			Apply nestedApply = (Apply)expression;
 
-			String negatedFunction = negate(nestedApply.getFunction());
+			String negatedFunction = negate(nestedApply.requireFunction());
 			if(negatedFunction != null){
 				expressionIt.remove();
 
@@ -107,6 +154,18 @@ public class ExpressionCompactor extends AbstractVisitor {
 		}
 	}
 
+	static
+	private boolean isMissingConstant(Expression expression){
+
+		if(expression instanceof Constant){
+			Constant constant = (Constant)expression;
+
+			return constant.isMissing();
+		}
+
+		return false;
+	}
+
 	static
 	private String negate(String function){
 
