@@ -30,7 +30,6 @@ import java.util.Set;
 import org.dmg.pmml.DataField;
 import org.dmg.pmml.DerivedField;
 import org.dmg.pmml.Field;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.LocalTransformations;
 import org.dmg.pmml.MiningField;
 import org.dmg.pmml.MiningSchema;
@@ -74,28 +73,24 @@ public class MiningSchemaCleaner extends DeepFieldResolver {
 	private Set<Field<?>> processMiningModel(MiningModel miningModel){
 		Set<Field<?>> activeFields = DeepFieldResolverUtil.getActiveFields(this, miningModel);
 
-		Set<FieldName> activeFieldNames = new HashSet<>();
+		Set<String> activeFieldNames = new HashSet<>();
 
-		Segmentation segmentation = miningModel.getSegmentation();
+		Segmentation segmentation = miningModel.requireSegmentation();
 
-		List<Segment> segments = segmentation.getSegments();
+		List<Segment> segments = segmentation.requireSegments();
 		for(Segment segment : segments){
-			Model model = segment.getModel();
+			Model model = segment.requireModel();
 
-			if(model == null){
-				continue;
-			}
-
-			MiningSchema miningSchema = model.getMiningSchema();
+			MiningSchema miningSchema = model.requireMiningSchema();
 
 			List<MiningField> miningFields = miningSchema.getMiningFields();
 			for(MiningField miningField : miningFields){
-				FieldName name = miningField.getName();
+				String fieldName = miningField.getName();
 
 				MiningField.UsageType usageType = miningField.getUsageType();
 				switch(usageType){
 					case ACTIVE:
-						activeFieldNames.add(name);
+						activeFieldNames.add(fieldName);
 						break;
 					default:
 						break;
@@ -132,21 +127,21 @@ public class MiningSchemaCleaner extends DeepFieldResolver {
 	}
 
 	private void clean(Model model, Set<Field<?>> activeFields){
-		MiningSchema miningSchema = model.getMiningSchema();
+		MiningSchema miningSchema = model.requireMiningSchema();
 
 		List<MiningField> miningFields = miningSchema.getMiningFields();
 
-		Map<FieldName, Field<?>> activeFieldMap = FieldUtil.nameMap(activeFields);
+		Map<String, Field<?>> activeFieldMap = FieldUtil.nameMap(activeFields);
 
 		for(Iterator<MiningField> it = miningFields.iterator(); it.hasNext(); ){
 			MiningField miningField = it.next();
 
-			FieldName name = miningField.getName();
+			String fieldName = miningField.getName();
 
 			MiningField.UsageType usageType = miningField.getUsageType();
 			switch(usageType){
 				case ACTIVE:
-					if(!(activeFieldMap).containsKey(name)){
+					if(!(activeFieldMap).containsKey(fieldName)){
 						it.remove();
 					}
 					break;
@@ -154,15 +149,13 @@ public class MiningSchemaCleaner extends DeepFieldResolver {
 					break;
 			}
 
-			activeFieldMap.remove(name);
+			activeFieldMap.remove(fieldName);
 		}
 
 		activeFields = new LinkedHashSet<>(activeFieldMap.values());
 
 		for(Field<?> activeField : activeFields){
-			FieldName name = activeField.getName();
-
-			MiningField miningField = new MiningField(name);
+			MiningField miningField = new MiningField(activeField);
 
 			miningSchema.addMiningFields(miningField);
 		}
@@ -201,7 +194,9 @@ public class MiningSchemaCleaner extends DeepFieldResolver {
 			}
 
 			private int getFieldType(MiningField miningField){
-				Field<?> field = activeFieldMap.get(miningField.getName());
+				String fieldName = miningField.getName();
+
+				Field<?> field = activeFieldMap.get(fieldName);
 
 				if(field instanceof DataField){
 					return 0;
