@@ -108,6 +108,7 @@ public class GLMConverter extends LMConverter {
 
 		GeneralRegressionModel generalRegressionModel = new GeneralRegressionModel(GeneralRegressionModel.ModelType.GENERALIZED_LINEAR, miningFunction, ModelUtil.createMiningSchema(label), null, null, null)
 			.setDistribution(parseFamily(familyFamily.asScalar()))
+			.setDistParameter(parseDistParameter(familyFamily.asScalar()))
 			.setLinkFunction(parseLinkFunction(familyLink.asScalar()))
 			.setLinkParameter(parseLinkParameter(familyLink.asScalar()));
 
@@ -131,10 +132,12 @@ public class GLMConverter extends LMConverter {
 		switch(distribution){
 			case BINOMIAL:
 				return MiningFunction.CLASSIFICATION;
-			case NORMAL:
 			case GAMMA:
 			case IGAUSS:
+			case NEGBIN:
+			case NORMAL:
 			case POISSON:
+			case TWEEDIE:
 				return MiningFunction.REGRESSION;
 			default:
 				throw new IllegalArgumentException();
@@ -144,6 +147,10 @@ public class GLMConverter extends LMConverter {
 	static
 	private GeneralRegressionModel.Distribution parseFamily(String family){
 
+		if(family.startsWith("Negative Binomial(")){
+			return GeneralRegressionModel.Distribution.NEGBIN;
+		}
+
 		switch(family){
 			case "binomial":
 				return GeneralRegressionModel.Distribution.BINOMIAL;
@@ -155,14 +162,37 @@ public class GLMConverter extends LMConverter {
 				return GeneralRegressionModel.Distribution.IGAUSS;
 			case "poisson":
 				return GeneralRegressionModel.Distribution.POISSON;
+			case "Tweedie":
+				return GeneralRegressionModel.Distribution.TWEEDIE;
 			default:
 				throw new IllegalArgumentException(family);
 		}
 	}
 
+	static
+	private Number parseDistParameter(String family){
+
+		if(family.startsWith("Negative Binomial(") && family.endsWith(")")){
+			return Double.valueOf(family.substring("Negative Binomial(".length(), family.length() - ")".length()));
+		}
+
+		switch(family){
+			default:
+				return null;
+		}
+	}
+
 	static
 	private GeneralRegressionModel.LinkFunction parseLinkFunction(String link){
 
+		if(link.startsWith("Negative Binomial(")){
+			return GeneralRegressionModel.LinkFunction.NEGBIN;
+		} else
+
+		if(link.startsWith("mu^")){
+			return GeneralRegressionModel.LinkFunction.POWER;
+		}
+
 		switch(link){
 			case "cloglog":
 				return GeneralRegressionModel.LinkFunction.CLOGLOG;
@@ -184,7 +214,11 @@ public class GLMConverter extends LMConverter {
 	}
 
 	static
-	private Double parseLinkParameter(String link){
+	private Number parseLinkParameter(String link){
+
+		if(link.startsWith("mu^")){
+			return Double.valueOf(link.substring("mu^".length()));
+		}
 
 		switch(link){
 			case "inverse":
