@@ -18,6 +18,8 @@
  */
 package org.jpmml.rexp;
 
+import java.io.IOException;
+import java.util.Collections;
 import java.util.List;
 
 import com.google.common.base.Function;
@@ -30,12 +32,49 @@ public class RBooleanVector extends RVector<Boolean> {
 	private int[] values = null;
 
 
+	public RBooleanVector(Boolean value, RPair attributes){
+		this(Collections.singletonList(value), attributes);
+	}
+
+	public RBooleanVector(List<Boolean> values, RPair attributes){
+		super(attributes);
+
+		this.values = values.stream()
+			.mapToInt(value -> {
+
+				if(value == null){
+					return Integer.MIN_VALUE;
+				}
+
+				return (value.booleanValue() ? 1 : 0);
+			})
+			.toArray();
+	}
+
 	public RBooleanVector(int[] values, RPair attributes){
 		super(attributes);
 
 		this.values = values;
 	}
 
+	@Override
+	int type(){
+		return SExpTypes.LGLSXP;
+	}
+
+	@Override
+	void writeValues(RDataOutput output) throws IOException {
+		int[] values = this.values;
+
+		int length = values.length;
+
+		output.writeInt(length);
+
+		for(int i = 0; i < length; i++){
+			output.writeInt(values[i]);
+		}
+	}
+
 	@Override
 	public DataType getDataType(){
 		return DataType.BOOLEAN;
