@@ -18,6 +18,8 @@
  */
 package org.jpmml.rexp;
 
+import java.io.IOException;
+
 abstract
 public class RExp {
 
@@ -28,6 +30,15 @@ public class RExp {
 		setAttributes(attributes);
 	}
 
+	@SuppressWarnings("unused")
+	public void write(RDataOutput output) throws IOException {
+		throw new UnsupportedOperationException();
+	}
+
+	public RStringVector _class(){
+		return getStringAttribute("class");
+	}
+
 	public RStringVector names(){
 		return getStringAttribute("names");
 	}
@@ -101,30 +112,30 @@ public class RExp {
 	}
 
 	public boolean hasAttribute(String name){
-		RPair attribute = getAttributes();
+		RPair attributes = getAttributes();
 
-		while(attribute != null){
+		while(attributes != null){
 
-			if(attribute.tagEquals(name)){
+			if(attributes.tagEquals(name)){
 				return true;
 			}
 
-			attribute = attribute.getNext();
+			attributes = attributes.getNext();
 		}
 
 		return false;
 	}
 
 	private RExp findAttribute(String name, boolean required){
-		RPair attribute = getAttributes();
+		RPair attributes = getAttributes();
 
-		while(attribute != null){
+		while(attributes != null){
 
-			if(attribute.tagEquals(name)){
-				return attribute.getValue();
+			if(attributes.tagEquals(name)){
+				return attributes.getValue();
 			}
 
-			attribute = attribute.getNext();
+			attributes = attributes.getNext();
 		}
 
 		if(required){
@@ -134,6 +145,32 @@ public class RExp {
 		return null;
 	}
 
+	public void addAttribute(String name, RExp rexp){
+		addAttribute(new RPair(new RString(name), rexp, null));
+	}
+
+	public void addAttribute(RPair pair){
+		RPair attributes = getAttributes();
+
+		if(attributes == null){
+			setAttributes(pair);
+
+			return;
+		}
+
+		while(attributes != null){
+			RPair next = attributes.getNext();
+
+			if(next == null){
+				break;
+			}
+
+			attributes = next;
+		}
+
+		attributes.setNext(pair);
+	}
+
 	public RPair getAttributes(){
 		return this.attributes;
 	}
