@@ -18,6 +18,7 @@
  */
 package org.jpmml.rexp;
 
+import java.io.Closeable;
 import java.io.EOFException;
 import java.io.IOException;
 import java.io.InputStream;
@@ -32,7 +33,7 @@ import java.util.zip.GZIPInputStream;
 
 import com.google.common.io.ByteStreams;
 
-public class RExpParser {
+public class RExpParser implements Closeable {
 
 	private RDataInput input = null;
 
@@ -44,7 +45,38 @@ public class RExpParser {
 
 
 	public RExpParser(InputStream is) throws IOException {
-		this.input = new XDRInput(init(new PushbackInputStream(is, 2)));
+		InputStream decompressedIs = maybeDecompress(new PushbackInputStream(is, 2));
+
+		PushbackInputStream pushbackIs = new PushbackInputStream(decompressedIs, 1);
+
+		int first = pushbackIs.read();
+
+		pushbackIs.unread(first);
+
+		if(first == 'A'){
+			this.input = new TextInput(pushbackIs){
+
+				@Override
+				public RExpParser getParser(){
+					return RExpParser.this;
+				}
+			};
+		} else
+
+		{
+			this.input = new BinaryInput(pushbackIs){
+
+				@Override
+				public RExpParser getParser(){
+					return RExpParser.this;
+				}
+			};
+		}
+	}
+
+	@Override
+	public void close() throws IOException {
+		this.input.close();
 	}
 
 	public RExp parse() throws IOException {
@@ -295,8 +327,12 @@ public class RExpParser {
 		}
 
 		RIntegerVector result = new RIntegerVector(values, readAttributes(flags));
-		if(result.hasAttribute("levels")){
-			result = new RFactorVector(values, result.getAttributes());
+		if(result.hasAttribute("class")){
+			RStringVector classNames = result._class();
+
+			if(classNames.indexOf("factor") > -1){
+				result = new RFactorVector(values, result.getAttributes());
+			}
 		}
 
 		return result;
@@ -559,7 +595,7 @@ public class RExpParser {
 	}
 
 	static
-	private InputStream init(PushbackInputStream is) throws IOException {
+	private InputStream maybeDecompress(PushbackInputStream is) throws IOException {
 		byte[] gzipMagic = new byte[2];
 
 		ByteStreams.readFully(is, gzipMagic);
