@@ -18,6 +18,8 @@
  */
 package org.jpmml.rexp;
 
+import java.io.IOException;
+
 public class RString extends RExp {
 
 	private String value = null;
@@ -29,6 +31,26 @@ public class RString extends RExp {
 		setValue(value);
 	}
 
+	@Override
+	public void write(RDataOutput output) throws IOException {
+		String value = getValue();
+
+		output.writeInt(SExpTypes.CHARSXP);
+
+		if(value == null){
+			output.writeInt(-1);
+		} else
+
+		{
+			value = output.escape(value);
+
+			byte[] bytes = value.getBytes();
+
+			output.writeInt(bytes.length);
+			output.writeByteArray(bytes);
+		}
+	}
+
 	public String getValue(){
 		return this.value;
 	}
